@@ -2,14 +2,17 @@ use crate::software_vault::SoftwareVault;
 use crate::VaultError;
 use arrayref::array_ref;
 use ockam_core::compat::vec::Vec;
+use ockam_core::Result;
+use ockam_core::{async_trait, compat::boxed::Box};
 use ockam_vault_core::{
     Hasher, Secret, SecretAttributes, SecretType, SecretVault, AES128_SECRET_LENGTH,
     AES256_SECRET_LENGTH,
 };
 use sha2::{Digest, Sha256};
 
+#[async_trait]
 impl Hasher for SoftwareVault {
-    fn sha256(&mut self, data: &[u8]) -> ockam_core::Result<[u8; 32]> {
+    async fn sha256(&mut self, data: &[u8]) -> Result<[u8; 32]> {
         let digest = Sha256::digest(data);
         Ok(*array_ref![digest, 0, 32])
     }
@@ -17,14 +20,14 @@ impl Hasher for SoftwareVault {
     /// Compute sha256.
     /// Salt and Ikm should be of Buffer type.
     /// Output secrets should be only of type Buffer or AES
-    fn hkdf_sha256(
+    async fn hkdf_sha256(
         &mut self,
         salt: &Secret,
         info: &[u8],
         ikm: Option<&Secret>,
         output_attributes: Vec<SecretAttributes>,
-    ) -> ockam_core::Result<Vec<Secret>> {
-        let ikm: ockam_core::Result<&[u8]> = match ikm {
+    ) -> Result<Vec<Secret>> {
+        let ikm: Result<&[u8]> = match ikm {
             Some(ikm) => {
                 let ikm = self.get_entry(ikm)?;
                 if ikm.key_attributes().stype() == SecretType::Buffer {
@@ -69,7 +72,7 @@ impl Hasher for SoftwareVault {
                 return Err(VaultError::InvalidHkdfOutputType.into());
             }
             let secret = &okm[index..index + length];
-            let secret = self.secret_import(secret, attributes)?;
+            let secret = self.secret_import(secret, attributes).await?;
 
             secrets.push(secret);
             index += 32;
